//  ************************************************************************************************
//
//  BornAgain: simulate and fit reflection and scattering
//
//! @file      GUI/Model/Descriptor/UIntDescriptor.cpp
//! @brief     Implements class UIntDescriptor
//!
//! @homepage  http://www.bornagainproject.org
//! @license   GNU General Public License v3 or higher (see COPYING)
//! @copyright Forschungszentrum Jülich GmbH 2021
//! @authors   Scientific Computing Group at MLZ (see CITATION, AUTHORS)
//
//  ************************************************************************************************

#include "GUI/Model/Descriptor/UIntDescriptor.h"

UIntDescriptor::UIntDescriptor(const QString& label, const QString& tooltip,
                               std::function<void(uint)> setter, std::function<uint()> getter,
                               const std::variant<QString, Unit>& unit)
    : UIntDescriptor(label, tooltip, RealLimits::nonnegative(), setter, getter, unit)
{
}

UIntDescriptor::UIntDescriptor(QString label, QString tooltip, const RealLimits& limits,
                               std::function<void(uint)> setter, std::function<uint()> getter,
                               const std::variant<QString, Unit>& unit)
    : label(std::move(label))
    , tooltip(std::move(tooltip))
    , limits(limits)
    , set(std::move(setter))
    , get(std::move(getter))
    , unit(unit)
{
}

UIntDescriptor::UIntDescriptor(const QString& label, const uint* var,
                               const std::variant<QString, Unit>& unit)
    : UIntDescriptor(
        label, "", RealLimits::nonnegative(), [=](uint v) { *const_cast<uint*>(var) = v; },
        [=] { return *var; }, unit)
{
}

UIntDescriptor::operator uint() const
{
    return get();
}
